# Changelog

## [0.0.5] - 2025-08-19
### Added
- Column type 'BLOB' (class bytes)
- New exception -> EncodeError
- CHANGELOG.md

### Fixed
- Some annotations bugs
- edit_table inappropriate name check
- Other small issues
- Copyright text
- README.MD

### Updated
- Annotations. Now project supports Python of 3.5 or higher version
- Required aiosqlite version

### Removed
- Documentation href

## [0.0.4] - 2025-08-08
### Added
- License

### Fixed
- Some annotations bugs